# calc.py
def add(x, y):
 return x + y
  
  
def sub(x, y):
 return x - y
  
# __init__.py
from .calc import add, sub